# spiking

[![PyPI version](https://badge.fury.io/py/spiking.svg)](https://badge.fury.io/py/spiking)  [![codecov](https://codecov.io/gh/doerlbh/spiking/branch/main/graph/badge.svg?token=)](https://codecov.io/gh/doerlbh/spiking) [![Travis_CI](https://travis-ci.com/doerlbh/spiking.svg?token=&branch=main)](https://travis-ci.com/doerlbh/spiking) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Python library

Created by [Baihan Lin](www.baihan.nyc), Columbia University
